==> tdm_3.0.1.tar.gz: tdm/R/all.Amidihirsm.R <==
all.Amidihirsm<-function(){
     cat("\n")                                                                       
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Theirsm_input()
     cat("-------------------------------------------------------------\n") 
     cat("\n")
     note_for_close_window()
     AmidihirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),
                                value=c(1,67,176,1,0,300,8))
     AmidihirSMMpar<-edit(AmidihirSMMpar)
##     AmidihirSMMpar<-ycheck(AmidihirSMMpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(AmidihirSMMpar);cat("\n\n")
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Thesm_conc_input()
     cat("-------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirSMpar<-data.frame(ts=c(4,8),conc=c(8.56,5.67))                                                                                                                             
     AmidihirSMpar<-edit(AmidihirSMpar)                                            
     ### AmidihirSMpar<-mscheck(AmidihirSMpar)            ### this must be remarked; otherwise, it may go wrong.                             
     cat("\n")
     cat("\n Input conc. are as follows:\n")
     cat(" --------------------------\n")
     show(AmidihirSMpar);cat("\n\n")
     Amidihir.sm(length(AmidihirSMpar$ts),AmidihirSMpar$conc,AmidihirSMpar$ts,AmidihirSMMpar[7,2],AmidihirSMMpar[6,2],AmidihirSMMpar[3,2],AmidihirSMMpar[2,2],AmidihirSMMpar[5,2],AmidihirSMMpar[1,2],AmidihirSMMpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--         \n")
     note_for_Theirsm_output()
     cat("------------------------------------------------------------------\n")
     ### show(samplesStats("*"))
     X <- read.table("params.csv",header=FALSE)
     cl_F <- X[1,2]
     v_F  <- X[2,2]
     cat("\n")
     Tmax<-log(1.85-(cl_F/v_F))/(1.85-(cl_F/v_F))
     C1<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],Tmax)
     ### sim<-matrix(C[1 ,1])
     ### show obs. and calc. conc. here  -YJ
     cat("\n\n")
     for(i in 1:length(AmidihirSMpar$ts)){
         Cx<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],AmidihirSMpar$ts[i]) 
         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(AmidihirSMpar$conc[i],Cx))
         cat("--- Theophylline plasma conc. (mg/L) at Time =",AmidihirSMpar$ts[i],"---\n")
         show(coutput);cat("\n")
     }
     C2<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],AmidihirSMMpar[7,2])
     coutput<-data.frame(conc=c("Cpss_pr (mg/L)","Ctss_pr (mg/L)"),calc=c(C1,C2))
     cat("\n");show(coutput);cat("\n\n")
     Amidihir.more()                   
}

==> tdm_3.0.2.tar.gz: tdm/R/all.Amidihirsm.R <==
all.Amidihirsm<-function(){
     cat("\n")                                                                       
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Theirsm_input()
     cat("-------------------------------------------------------------\n") 
     cat("\n")
     note_for_close_window()
     AmidihirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),
                                value=c(1,67,176,1,0,300,8))
     AmidihirSMMpar<-edit(AmidihirSMMpar)
##     AmidihirSMMpar<-ycheck(AmidihirSMMpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(AmidihirSMMpar);cat("\n\n")
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Thesm_conc_input()
     cat("-------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirSMpar<-data.frame(ts=c(4,8),conc=c(8.56,5.67))                                                                                                                             
     AmidihirSMpar<-edit(AmidihirSMpar)                                            
     ### AmidihirSMpar<-mscheck(AmidihirSMpar)            ### this must be remarked; otherwise, it may go wrong.                             
     cat("\n")
     cat("\n Input conc. are as follows:\n")
     cat(" --------------------------\n")
     show(AmidihirSMpar);cat("\n\n")
     Amidihir.sm(length(AmidihirSMpar$ts),AmidihirSMpar$conc,AmidihirSMpar$ts,AmidihirSMMpar[7,2],AmidihirSMMpar[6,2],AmidihirSMMpar[3,2],AmidihirSMMpar[2,2],AmidihirSMMpar[5,2],AmidihirSMMpar[1,2],AmidihirSMMpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--         \n")
     note_for_Theirsm_output()
     cat("------------------------------------------------------------------\n")
     ### show(samplesStats("*"))
     X <- read.table("params.csv",header=FALSE)
     cl_F <- X[1,2]
     v_F  <- X[2,2]
     cat("\n")
     Tmax<-log(1.85/(cl_F/v_F))/(1.85-(cl_F/v_F))
     C1<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],Tmax)
     ### sim<-matrix(C[1 ,1])
     ### show obs. and calc. conc. here  -YJ
     cat("\n\n")
     for(i in 1:length(AmidihirSMpar$ts)){
         Cx<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],AmidihirSMpar$ts[i]) 
         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(AmidihirSMpar$conc[i],Cx))
         cat("--- Theophylline plasma conc. (mg/L) at Time =",AmidihirSMpar$ts[i],"---\n")
         show(coutput);cat("\n")
     }
     C2<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],AmidihirSMMpar[7,2])
     coutput<-data.frame(conc=c("Cpss_pr (mg/L)","Ctss_pr (mg/L)"),calc=c(C1,C2))
     cat("\n");show(coutput);cat("\n\n")
     Amidihir.more()                   
}
